@@ -32,7 +32,7 @@ main (int argc, char *argv[])
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-  app = phosh_tour_application_new ("sm.puri.PhoshTour",
+  app = phosh_tour_application_new (PHOSH_TOUR_APP_ID,
 #if GLIB_CHECK_VERSION(2,74,0)
                                          G_APPLICATION_DEFAULT_FLAGS);
 #else
